@@ -20,7 +20,9 @@
 #ifndef __LOG_ABOUT_H__
 #define __LOG_ABOUT_H__
 
-void AboutShowWindow (GtkWidget *widget, gpointer user_data);
+#include <gtk/gtk.h>
+
+void logview_about (GtkWidget *widget, GtkWidget *window);
 
 #endif /* __LOG_ABOUT_H__ */
 
