@@ -20,6 +20,10 @@
 #ifndef __LOG_REPAINT_H__
 #define __LOG_REPAINT_H__
 
+#include <gtk/gtk.h>
+
+#include "logview.h"
+
 void logview_repaint (LogviewWindow *window);
 void selection_changed_cb (GtkTreeSelection *selection, gpointer data);
 void row_toggled_cb (GtkTreeView *treeview, GtkTreeIter *iter, 
