@@ -25,12 +25,13 @@
 #include <config.h>
 #endif
 #include <gtk/gtk.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <glib/gi18n.h>
 #include <string.h>
 #include <stdlib.h>
+
 #include "logview.h"
 #include "logrtns.h"
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include "misc.h"
 #include "math.h"
 
@@ -252,7 +253,11 @@ log_read_dates (gchar **buffer_lines, time_t current)
            i++;
            date_string = string_get_date_string (buffer_lines[i]);
            if (date_string == NULL)
-             continue;
+             if (i==n-1) {
+               done = TRUE;
+               break;
+             } else
+               continue;
            newdate = string_get_date (buffer_lines[i]);
            
            if (newdate == NULL && i==n-1)
@@ -441,16 +446,14 @@ log_open (char *filename, gboolean show_error)
 
    return log;
 
-   /* Error catching */
-
- error:
-
+error:
    if (error_message && show_error) {
        error_dialog_show (NULL, error_main, error_message);
-       g_free (error_message);
    }
-   return NULL;
    
+   g_free (error_message);
+   
+   return NULL;
 }
 
 static void
