@@ -23,6 +23,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+
 #include "logview.h"
 #include "loglist.h"
 #include "log_repaint.h"
@@ -48,12 +49,10 @@ enum {
   LOG_LINE_WEIGHT_SET
 };
 
-static GObjectClass *parent_class;
+G_DEFINE_TYPE (LogviewWindow, logview_window, GTK_TYPE_WINDOW);
 
 /* Function Prototypes */
 
-GType logview_window_get_type (void);
-
 static void logview_save_prefs (LogviewWindow *logview);
 static void logview_add_log (LogviewWindow *logview, Log *log);
 static void logview_menu_item_set_state (LogviewWindow *logview, char *path, gboolean state);
@@ -766,13 +765,16 @@ logview_calendar_set_state (LogviewWindow *logview)
 static void
 logview_help (GtkAction *action, GtkWidget *parent_window)
 {
-    GError *error = NULL;                                                                                
-    gnome_help_display_desktop_on_screen (NULL, "gnome-system-log", "gnome-system-log", NULL,
-                                          gtk_widget_get_screen (GTK_WIDGET(parent_window)), &error);
-	if (error) {
-		error_dialog_show (GTK_WIDGET(parent_window), _("There was an error displaying help."), error->message);
-		g_error_free (error);
-	}
+    GError *error = NULL;
+
+    gtk_show_uri (gtk_widget_get_screen (parent_window),
+                  "ghelp:gnome-system-log", gtk_get_current_event_time (),
+                  &error);
+
+    if (error) {
+        error_dialog_show (parent_window, _("There was an error displaying help."), error->message);
+        g_error_free (error);
+    }
 }
 
 static gboolean 
@@ -792,11 +794,11 @@ logview_window_finalize (GObject *object)
     LogviewWindow *logview = LOGVIEW_WINDOW(object);
 
     g_object_unref (logview->ui_manager);
-    parent_class->finalize (object);
+    G_OBJECT_CLASS (logview_window_parent_class)->finalize (object);
 }
 
 static void
-logview_init (LogviewWindow *logview)
+logview_window_init (LogviewWindow *logview)
 {
    GtkWidget *vbox;
    GtkTreeStore *tree_store;
@@ -968,7 +970,6 @@ logview_window_class_init (LogviewWindowClass *klass)
 
 	object_class->finalize = logview_window_finalize;
 	object_class->get_property = logview_window_get_property;
-	parent_class = g_type_class_peek_parent (klass);
 
 	g_object_class_install_property (object_class, PROP_DAYS,
 					 g_param_spec_pointer ("days",
@@ -977,30 +978,6 @@ logview_window_class_init (LogviewWindowClass *klass)
 					 (G_PARAM_READABLE)));
 }
 
-GType
-logview_window_get_type (void)
-{
-	static GType object_type = 0;
-	
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (LogviewWindowClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) logview_window_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (LogviewWindow),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) logview_init
-		};
-
-		object_type = g_type_register_static (GTK_TYPE_WINDOW, "LogviewWindow", &object_info, 0);
-	}
-
-	return object_type;
-}
-
 GtkWidget *
 logview_window_new ()
 {
